# docx-charts

Python library for manipulating chart data in word documents

Disclaimer: this is a project made for a very specific usecase, because nothing better existed yet. No stability guarantees are made, and the API is subject to change :)
